<!DOCTYPE html>
<html lang="en">
<head>

    <meta charset="UTF-8">
    <meta name="viewport" content="width=1024">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <title>Print Invoice - <?php echo e(get_setting('title')); ?> </title>

    <link rel="stylesheet" href="<?php echo e(static_asset('front/css/bootstrap.min.css')); ?>">
    <link rel="stylesheet" href="<?php echo e(static_asset('front/css/fontAwesome5Pro.css')); ?>">
    <link rel="stylesheet" href="<?php echo e(static_asset('front/css/print.css')); ?>">

    <link rel="shortcut icon" type="image/x-icon" href="<?php echo e(my_asset(get_setting('favicon'))); ?>">
    <style>
        .bkg-img, body {
            background-image: url('https://img.freepik.com/premium-vector/abstract-blue-geometric-technology-background_41814-239.jpg?w=900');
            background-repeat: no-repeat;
            background-attachment: fixed;
            background-size: cover;
        }
    </style>
</head>
<body>
    <div class="body-wrapper sbkg-img">
        <div class="bodywrapper__inner">
            <div class="d-flex mb-30 flex-wrap gap-3 justify-content-between align-items-center">
                <h6 class="page-title">Print Invoice </h6>
                <div class="d-flex flex-wrap justify-content-end gap-2 align-items-center breadcrumb-plugins">
                    <a href="#" class="btn btn-sm btn-outline--primary"> <i class="fa fa-undo"></i> Back</a>
                </div>
            </div>

            <div class="card bkg-img">
                <div class="card-body">
                    <div id="printInvoice" class="mt-3 bkg-img">
                        <table width="100%">
                            <tbody>
                                <tr>
                                    <td style="border: 0; text-align: left;" width="18%">
                                        <div id="logo">
                                            <img src="<?php echo e(my_asset(get_setting('logo'))); ?>" alt="<?php echo e(get_setting('title')); ?>" width="150" height="45" />
                                        </div>
                                    </td>
                                    <td style="border: 0; text-align: center;" width="50%">
                                        
                                        Phone: <?php echo e(get_setting('phone')); ?><br />
                                        Email: <?php echo e(get_setting('email')); ?><br />
                                        Street: <?php echo e(get_setting('address')); ?>

                                    </td>
                                    <td style="border: 0; text-align: center;" width="48%">
                                        <br />
                                        <div class=""><?php echo DNS1D::getBarcodeHTML($shipment->code, 'C128'); ?></div>
                                        <?php echo e($shipment->code); ?>


                                    </td>
                                </tr>
                            </tbody>
                        </table>

                        <div class="content-header">
                            <h3>
                                Invoice Number :
                                <small>#<?php echo e($shipment->code); ?></small>
                                <br />
                                Date: <?php echo e(show_datetime($shipment->shipment_date)); ?>

                                <br />
                                Estimate Delivery Date : <?php echo e(show_date($shipment->delivery_date)); ?>

                            </h3>
                        </div>

                        <div class="invoice">
                            <div class="d-flex justify-content-between mt-3">
                                <div class="text-center">
                                    <span> </span>
                                </div>
                                <div>
                                    <b>Order ID : <?php echo e($shipment->code); ?></b><br />


                                </div>
                            </div>
                            <hr />

                            <td style="border: 1; text-align: left;" width="20%">PACKAGE INFORMATION</td>
                            <div class="invoice-info d-flex justify-content-between">
                                <div>
                                    From
                                    <address>
                                        <strong><?php echo e($shipment->sender_name); ?></strong><br />
                                        Address: <?php echo e($shipment->sender_address); ?><br />
                                        Phone: <?php echo e($shipment->sender_phone); ?><br />
                                        Email: <?php echo e($shipment->sender_email); ?>

                                    </address>
                                </div>
                                <div>
                                    To
                                    <address>
                                        <strong><?php echo e($shipment->receiver_name); ?></strong><br />
                                        Address: <?php echo e($shipment->receiver_address); ?><br />
                                        Phone: <?php echo e($shipment->receiver_phone); ?><br />
                                        Email: <?php echo e($shipment->receiver_email); ?>

                                    </address>
                                </div>
                            </div>

                            <div class="row">
                                <div class="col-12">
                                    <table class="table table-striped">
                                        <thead>
                                            <tr>
                                                <th>Qty</th>
                                                <th>Courier Type</th>
                                                <th>Description</th>
                                                <th>Sending Time</th>
                                                
                                                <th>Payment</th>
                                                
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <tr>
                                                <td data-label="#">1</td>
                                                <td data-label="Courier Type"><span class="badge bg-info"> <?php echo e($shipment->package_type); ?> </span> </td>
                                                <td><?php echo e($shipment->description); ?></td>
                                                <td data-label="Sending Time"><?php echo e(show_datetime1($shipment->shipment_date)); ?></td>
                                                
                                                <td data-label="Status"><b class="badge fw-bold bg-info"><?php echo e(payment_status($shipment->payment_status)); ?></b></td>
                                                
                                            </tr>
                                        </tbody>
                                    </table>
                                </div>
                            </div>

                            <hr />
                        </div>
                    </div>
                    <div class="row no-print">
                        <div class="col-sm-12">
                            <div class="float-sm-end">
                                <button onclick="window.print()">Print Invoice</button>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- bodywrapper__inner end -->
    </div>




    <script src="https://script.viserlab.com/courierlab/assets/global/js/jquery-3.6.0.min.js"></script>
    <script src="https://script.viserlab.com/courierlab/assets/global/js/bootstrap.bundle.min.js"></script>

    <script src="https://script.viserlab.com/courierlab/assets/viseradmin/js/printThis.js"></script>

    pr
</body>
</html><?php /**PATH /home/zpvgxjex/public_html/directexpress.couriers-co.com/resources/views/front/print.blade.php ENDPATH**/ ?>